@@ -8,4 +8,4 @@ echo "This is my test" > /tmp/fortune
 
 cd debian/tests/images-for-seek
 
-seek_script
+seek_script || exit 77
